diff src/status.h @ 10348:64bc206c7473

[gaim-migrate @ 11562] Ability to read sub-statuses from ~/.gaim/status.xml. We don't actually WRITE these to the file yet, so this doesn't do anything. Also a few other minor changes elsewhere. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Sun, 12 Dec 2004 23:57:52 +0000
parents 84d73473c019
children bed2c96bc1fb
line wrap: on
line diff
--- a/src/status.h	Sun Dec 12 18:20:17 2004 +0000
+++ b/src/status.h	Sun Dec 12 23:57:52 2004 +0000
@@ -58,7 +58,8 @@
 	GAIM_STATUS_UNAVAILABLE,
 	GAIM_STATUS_HIDDEN,
 	GAIM_STATUS_AWAY,
-	GAIM_STATUS_EXTENDED_AWAY
+	GAIM_STATUS_EXTENDED_AWAY,
+	GAIM_STATUS_NUM_PRIMITIVES
 
 } GaimStatusPrimitive;
 
@@ -296,6 +297,18 @@
  */
 const GList *gaim_status_type_get_attrs(const GaimStatusType *status_type);
 
+/**
+ * Find the GaimStatusType with the given id.
+ *
+ * @param status_types A list of status types.  Often account->status_types.
+ * @param id The unique ID of the status type you wish to find.
+ *
+ * @return The status type with the given ID, or NULL if one could
+ *         not be found.
+ */
+const GaimStatusType *gaim_status_type_find_with_id(GList *status_types,
+													const char *id);
+
 /*@}*/
 
 /**************************************************************************/
@@ -896,11 +909,20 @@
 /**
  * Finds a saved status with the specified title.
  *
  * @param name The name of the saved status.
  *
  * @return The saved status if found, or NULL.
  */
-GaimStatusSaved *gaim_statuses_find_saved(const char *name);
+GaimStatusSaved *gaim_statuses_find_saved(const char *title);
+
+/**
+ * Return the name of a given saved status.
+ *
+ * @param saved_status The saved status.
+ *
+ * @return The title.
+ */
+const char *gaim_statuses_saved_get_title(const GaimStatusSaved *saved_status);
 
 /**
  * Return the name of a given saved status.
@@ -909,16 +931,7 @@
  *
  * @return The name.
  */
-const char *gaim_statuses_saved_get_name(const GaimStatusSaved *saved_status);
-
-/**
- * Return the name of a given saved status.
- *
- * @param saved_status The saved status.
- *
- * @return The name.
- */
-const GaimStatusType *gaim_statuses_saved_get_type(const GaimStatusSaved *saved_status);
+GaimStatusPrimitive gaim_statuses_saved_get_type(const GaimStatusSaved *saved_status);
 
 /**
  * Return the name of a given saved status.
@@ -947,15 +960,15 @@
 void gaim_statuses_uninit(void);
 
 /**
+ * Syncs status information from a file.
+ */
+void gaim_statuses_load(void);
+
+/**
  * Syncs status information to the file.
  */
 void gaim_statuses_sync(void);
 
-/**
- * Syncs status information from a file.
- */
-void gaim_statuses_load(void);
-
 /*@}*/
 
 #endif /* _GAIM_STATUS_H_ */
@@ -896,11 +909,20 @@
  * Finds a saved status with the specified title.
  *
- * @param name The name of the saved status.
+ * @param title The name of the saved status.
  *
  * @return The saved status if found, or NULL.